require_relative 'cli_helper'

module Vcs2JsonCLI
  class Main < Thor
      map %w[--version -v] => :__print_version

      class_option :logger_level, type: :string, default: 'error', desc: "The severity level to output to log"
      class_option :logger_location, type: :string, desc: "Which file to print logs to"

      desc "--version, -v", "print the version"
      def __print_version
          puts Vcs2Json::VERSION
      end

      ##
      # default thor behavior is to return exit 0 on errors (i.e., success..)
      # by having exit_on_failure return true, exit(1) is returned instead
      def self.exit_on_failure?
        true
      end

      class_option :ignore, type: :string, desc: "Specify location of .evocignore file"
      class_option :case_id, type: :string, desc: "Specify case identifier. Used by .evocignore etc"
      class_option :issue, :aliases => '-i', :type => :boolean, :default => false, :desc => "Attempt to extract issue ids from commit messages"
      class_option :after, :aliases => '-a', :desc => "Only include commits after this date"
      class_option :before, :aliases => '-b', :desc => "Only include commits before this date"
      class_option :number, :aliases => '-n', type: :numeric, default: 10000, :desc => "The number of commits to dump"
      class_option :fine_grained, type: :boolean, default: true, desc: "Include fine grained change information in output"
      class_option :ignore_comments, type: :boolean, default: false, desc: "Ignore comments when calculating diffs. Only in effect for fine grained changes."
      class_option :ignore_whitespace, type: :boolean, default: false, desc: "Ignore whitespace when calculating diffs. Only in effect for fine grained changes."
      class_option :residuals, type: :boolean, default: true, desc: "Consider changes that happen outside of methods"


      desc "git [options]","Make a dump of the change-history of system using git, output on stdout"
      def git
          Vcs2Json::Git.new(options).parse
      end

      # the default is to use git
      default_task :git
  end
end
