# enable logging in classes through 'include Logging'
module Logging
  def logger
    @logger ||= Logging.logger_for(self.class.name)
  end

  # Use a hash class-ivar to cache a unique Logger per class:
  @loggers = {}
  @logger_level = 'debug'
  @logger_location = 'vcs2json.log'

  class << self
    def logger_for(classname)
      @loggers[classname] ||= configure_logger_for(classname)
    end

    def configure_logger_for(classname)
      begin
        logger = Logger.new(@logger_location,'daily')
      rescue Errno::EACCES
        tmp = Tempfile.new('vcs2json')
        $stderr.puts "Tried to create a logging file here: '#{@logger_location}', but didn't have permission, defaulting to OS temp firectory: #{tmp.path}"
        logger = Logger.new(tmp,'daily')
      end
      logger.progname = classname
      logger.level = const_get('Logger::'+@logger_level.upcase)
      logger
    end

    def set_location(path)
      @logger_location = path
    end

    def set_level(level)
      possible_levels = %w(debug info warn error info)
      if !level.nil?
        if !level.empty?
          if possible_levels.include?(level)
            STDERR.puts "Logging level has been set to '#{level}' for output to #{@logger_location}"
            @loggers.each {|l| l.level = const_get('Logger::'+level.upcase)}
            @logger_level = level
          else
            STDERR.puts "Unable to set logger level to #{level}, possible values are #{possible_levels}. Defaulting to 'info'."
          end
        end
      end
    end
  end
end
